Difftastic is a syntactic diff tool.
For usage instructions and advice on contributing, see the manual.
Structs
Enums
Functions
- main_
entry - The entrypoint.
- render_
diff_ from_ paths
Difftastic is a syntactic diff tool.
For usage instructions and advice on contributing, see the manual.